Convert Endpoints
=================

List All Convert Pairs
----------------------
.. autofunction:: binance.spot.Spot.list_all_convert_pairs

Query order quantity precision per asset (USER_DATA)
----------------------------------------------------
.. autofunction:: binance.spot.Spot.query_order_quantity_precision_per_asset

Send quote request (USER_DATA)
------------------------------
.. autofunction:: binance.spot.Spot.send_quote_request

Accept Quote (TRADE)
--------------------
.. autofunction:: binance.spot.Spot.accept_quote

Order Status (USER_DATA)
------------------------
.. autofunction:: binance.spot.Spot.order_status

Place limit order (USER_DATA)
-----------------------------
.. autofunction:: binance.spot.Spot.place_limit_order

Cancel limit order (USER_DATA)
------------------------------
.. autofunction:: binance.spot.Spot.cancel_limit_order

Query limit open orders (USER_DATA)
-----------------------------------
.. autofunction:: binance.spot.Spot.query_limit_open_order

Get Convert Trade History (USER_DATA)
-------------------------------------
.. autofunction:: binance.spot.Spot.get_convert_trade_history
